@@ -116,6 +116,23 @@ class binance:
             return response['msg']
         return price
 
+    def prices(self,symbols:list,base_asset):
+        '''Function to get list of symbols prices in one request'''
+        result =[]
+        response = requests.get('https://api.binance.com/api/v3/ticker/bookTicker',params={}).json()
+        for symbol in symbols:
+            symbol = self.symbol_format(symbol+base_asset)
+            for price in response:
+                if price['symbol']==symbol:
+                    try:
+                        bid=float(price['bidPrice'])
+                        ask=float(price['askPrice'])
+                        price={'symbol':symbol,'bid':bid,'ask':ask}
+                        result.append(price)
+                    except:
+                        return response['msg']
+        return result
+
     def account_information(self):
         '''Function to get account information'''
         timestamp = self.get_server_time()
@@ -875,6 +892,25 @@ class ftx:
             return e
 
 
+    def prices(self,symbols:list,base_asset):
+        '''Function to get list of symbols prices in one request'''
+        result =[]
+        response = self.get_exchange_info()['result']
+        for symbol in symbols:
+            symbol = self.symbol_format(symbol+'/'+base_asset)
+            for price in response:
+                if price['name']==symbol:
+                    try:
+                        bid=float(price['bid'])
+                        ask=float(price['ask'])
+                        price={'symbol':symbol,'bid':bid,'ask':ask}
+                        result.append(price)
+                    except:
+                        return response['msg']
+        return result
+
+
+
     def get_balances(self,asset) -> dict:
         '''Function to get account balances'''
         response = self._get('wallet/balances')
